@@ -1,4 +1,4 @@
-! Testing for LOCK with ACQUIRED_LOCK= specifier. 
+! Testing for LOCK & UNLOCK with ACQUIRED_LOCK= specifier
 ! Case: Successful locking
 
       program lock_unlock
@@ -17,17 +17,21 @@
           print * , "Config Error: NPROCS should be greater than 1"
         end if
 
-	acq_stat=.FALSE.
+	acq_stat=.TRUE.
 
         if (me == 1) then
-          LOCK(lock_var, ACQUIRED_LOCK=acq_stat)
-          if (acq_stat) then
-	    print *, "acq_stat == .TRUE.: ", me
+          LOCK(lock_var)
+	  call sleep(5*SLEEP)
+	else
+	  call sleep(SLEEP)
+          LOCK(lock_var[1], ACQUIRED_LOCK=acq_stat)
+          if (.NOT. acq_stat) then
+	    print *, "acq_stat == .FALSE.: ", me
 	  else
-            print *, "Error:acq_stat /= .TRUE.: ", me
+            print *, "Error:acq_stat /= .FALSE.: ", me
             err_cnt = 1
           end if
-          UNLOCK(lock_var,STAT=stat_var)
+          UNLOCK(lock_var, STAT=stat_var)
         end if
 
         if (err_cnt == 1) then
